Learn R Programming

gems (version 1.0.0)

ArtCohort: Class "ArtCohort"

Description

Is a S4 class for the artificial cohort generated by simulateCohort.

Usage

"["(x, i, j, ..., drop = TRUE)
"update"(object, newsize, addbaseline = matrix(NA, nrow = newsize - object@size), newInitialStates = rep(1, newsize - object@size))
"head"(x, ...)
"tail"(x, ...)
"summary"(object)

Arguments

x,object
an ArtCohort
i,j,drop
same as for data.frame
...
passed on to data.frame method
newsize
size of the updated cohort
addbaseline
baseline for new part of cohort
newInitialStates
initial states for new part of cohort

Slots

states.number
Object of class "numeric": number of states
size
Object of class "numeric": cohort size
baseline
Object of class "matrix": baseline matrix
follow.up
Object of class "numeric": maximum follow-up time
parameters
Object of class "transition.structure": input parameters
parametersCovariances
Object of class "transition.structure": input covariance matrices
timeToTransition
Object of class "matrix": input timeToTransition matrix. logical components
transitionFunctions
Object of class "transition.structure": input hazard functions
time.to.state
Object of class "data.frame": entry times for each patient into each of the states

Objects from the Class

Objects are created by calls to the function simulateCohort.

See Also

simulateCohort, transition.structure, transitionProbabilities, cumulativeIncidence

Examples

Run this code
showClass("ArtCohort")

Run the code above in your browser using DataLab