cumulativeIncidence: transition probabilities
Description
Calculates the cumulative incidence and prediction intervals after first
state
Usage
cumulativeIncidence(object, times, M = 100, stateNames = paste("State", as.list(1:dim(cohorts)[1])))
Arguments
object
either the output of simulateCohort or the
matrix with the probabilities slot of that output. M
number of groups for calculating confidence intervals.
stateNames
a list with the names of states.
Value
an object of class "PosteriorProbabilities", containing the
statenames, timepoints and the cumulative incidence with pointwise
prediction intervals over time.
References
Nello Blaser, Luisa Salazar Vizcaya, Janne Estill, Cindy Zahnd,
Bindu Kalesan, Matthias Egger, Olivia Keiser, Thomas Gsponer (2015). gems:
An R Package for Simulating from Disease Progression Models. Journal of
Statistical Software, 64(10), 1-22. URL http://www.jstatsoft.org/v64/i10/.