Learn R Programming

gems (version 1.1.0)

generateParameterCovarianceMatrix: generate a template for parameter covariances

Description

This function simplifies generating the matrix of parameter covariances from a matrix of mean parameters.

Usage

generateParameterCovarianceMatrix(mu)

Arguments

mu
a transition.structure of dimension $N x N$, whose components list the mean values for the parameters in the transitionFunction.

Value

a transition.structure of dimension $N x N$ of covariance matrices for the parameters.

References

Nello Blaser, Luisa Salazar Vizcaya, Janne Estill, Cindy Zahnd, Bindu Kalesan, Matthias Egger, Olivia Keiser, Thomas Gsponer (2015). gems: An R Package for Simulating from Disease Progression Models. Journal of Statistical Software, 64(10), 1-22. URL http://www.jstatsoft.org/v64/i10/.

See Also

transition.structure, generateParameterMatrix, simulateCohort