Learn R Programming

gems (version 0.9.5)

cumulativeIncidence: transition probabilities

Description

Calculates the cumulative incidence and prediction intervals after first state

Usage

cumulativeIncidence(object, times, M=100,
  stateNames = paste("State", as.list(1:dim(cohorts)[1])))

Arguments

object
either the output of simulateCohort or the matrix with the probabilities slot of that output.
times
a time vector.
M
number of groups for calculating confidence intervals.
stateNames
a list with the names of states.

Value

  • an object of class "PosteriorProbabilities", containing the statenames, timepoints and the cumulative incidence with pointwise prediction intervals over time.

See Also

PosteriorProbabilities-class, ArtCohort-class, simulateCohort