Learn R Programming

gems (version 0.9.5)

generateParameterCovarianceMatrix: generate a template for parameter covariances

Description

This function simplifies generating the matrix of parameter covariances from a matrix of mean parameters.

Usage

generateParameterCovarianceMatrix(mu)

Arguments

mu
a transition.structure of dimension $N \times N$, whose components list the mean values for the parameters in the transitionFunction.

Value

  • a transition.structure of dimension $N \times N$ of covariance matrices for the parameters.

See Also

transition.structure-class, generateParameterMatrix, simulateCohort